@@ -1066,7 +1066,7 @@ class TransactionServiceApi:
             collection_formats=collection_formats)
 
     def get_latest_transaction_line_item_version(self, space_id, id, **kwargs):
-        """getLatestTransactionLineItemVersion
+        """getLatestSuccessfulTransactionLineItemVersion
 
         
         This method makes a synchronous HTTP request by default. To make an
@@ -1091,7 +1091,7 @@ class TransactionServiceApi:
             return data
 
     def get_latest_transaction_line_item_version_with_http_info(self, space_id, id, **kwargs):
-        """getLatestTransactionLineItemVersion
+        """getLatestSuccessfulTransactionLineItemVersion
 
         
         This method makes a synchronous HTTP request by default. To make an
@@ -1908,112 +1908,3 @@ class TransactionServiceApi:
             _preload_content=params.get('_preload_content', True),
             _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
-
-    def update_transaction_line_items(self, space_id, update_request, **kwargs):
-        """updateTransactionLineItems
-
-        
-        This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
-        >>> thread = api.update_transaction_line_items(space_id, update_request, async_req=True)
-        >>> result = thread.get()
-
-        :param async_req bool
-        :param int space_id:  (required)
-        :param TransactionLineItemUpdateRequest update_request:  (required)
-        :return: TransactionLineItemVersion
-                 If the method is called asynchronously,
-                 returns the request thread.
-        """
-        kwargs['_return_http_data_only'] = True
-
-
-        if kwargs.get('async_req'):
-            return self.update_transaction_line_items_with_http_info(space_id, update_request, **kwargs)
-        else:
-            (data) = self.update_transaction_line_items_with_http_info(space_id, update_request, **kwargs)
-            return data
-
-    def update_transaction_line_items_with_http_info(self, space_id, update_request, **kwargs):
-        """updateTransactionLineItems
-
-        
-        This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
-        >>> thread = api.update_transaction_line_items_with_http_info(space_id, update_request, async_req=True)
-        >>> result = thread.get()
-
-        :param async_req bool
-        :param int space_id:  (required)
-        :param TransactionLineItemUpdateRequest update_request:  (required)
-        :return: TransactionLineItemVersion
-                 If the method is called asynchronously,
-                 returns the request thread.
-        """
-
-        all_params = ['space_id', 'update_request']
-        all_params.append('async_req')
-        all_params.append('_return_http_data_only')
-        all_params.append('_preload_content')
-        all_params.append('_request_timeout')
-
-        params = locals()
-        for key, val in six.iteritems(params['kwargs']):
-            if key not in all_params:
-                raise TypeError(
-                    "Got an unexpected keyword argument '%s'"
-                    " to method update_transaction_line_items" % key
-                )
-            params[key] = val
-        del params['kwargs']
-        # verify the required parameter 'space_id' is set
-        if ('space_id' not in params or
-                params['space_id'] is None):
-            raise ValueError("Missing the required parameter `space_id` when calling `update_transaction_line_items`")
-        # verify the required parameter 'update_request' is set
-        if ('update_request' not in params or
-                params['update_request'] is None):
-            raise ValueError("Missing the required parameter `update_request` when calling `update_transaction_line_items`")
-
-        collection_formats = {}
-
-        path_params = {}
-
-        query_params = []
-        if 'space_id' in params:
-            query_params.append(('spaceId', params['space_id']))
-
-        header_params = {}
-
-        form_params = []
-        local_var_files = {}
-
-        body_params = None
-        if 'update_request' in params:
-            body_params = params['update_request']
-        # HTTP header `Accept`
-        header_params['Accept'] = self.api_client.select_header_accept(
-            ['application/json;charset=utf-8'])
-
-        # HTTP header `Content-Type`
-        header_params['Content-Type'] = self.api_client.select_header_content_type(
-            ['application/json;charset=utf-8'])
-
-        # Authentication setting
-        auth_settings = []
-
-        return self.api_client.call_api(
-            '/transaction/updateTransactionLineItems', 'POST',
-            path_params,
-            query_params,
-            header_params,
-            body=body_params,
-            post_params=form_params,
-            files=local_var_files,
-            response_type='TransactionLineItemVersion',
-            auth_settings=auth_settings,
-            async_req=params.get('async_req'),
-            _return_http_data_only=params.get('_return_http_data_only'),
-            _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('_request_timeout'),
-            collection_formats=collection_formats)
